@@ -183,6 +183,7 @@ class FileFd
 
    private:
    FileFdPrivate * d;
+   APT_HIDDEN FileFd(const FileFd &);
    APT_HIDDEN FileFd & operator=(const FileFd &);
    APT_HIDDEN bool OpenInternDescriptor(unsigned int const Mode, APT::Configuration::Compressor const &compressor);
 
@@ -209,6 +210,12 @@ FileFd* GetTempFile(std::string const &Prefix = "",
                     bool ImmediateUnlink = true,
 		    FileFd * const TmpFd = NULL);
 
+// FIXME: GetTempFile should always return a buffered file
+FileFd* GetTempFile(std::string const &Prefix,
+                    bool ImmediateUnlink ,
+		    FileFd * const TmpFd,
+          bool Buffered) APT_HIDDEN;
+
 /** \brief Ensure the existence of the given Path
  *
  *  \param Parent directory of the Path directory - a trailing
@@ -278,7 +285,7 @@ std::vector<std::string> Glob(std::string const &pattern, int flags=0);
 /** \brief Popen() implementation that execv() instead of using a shell
  *
  * \param Args the execv style command to run
- * \param FileFd is a referenz to the FileFd to use for input or output
+ * \param FileFd is a reference to the FileFd to use for input or output
  * \param Child a reference to the integer that stores the child pid
  *        Note that you must call ExecWait() or similar to cleanup
  * \param Mode is either FileFd::ReadOnly or FileFd::WriteOnly
@@ -293,6 +300,4 @@ bool Popen(const char* Args[], FileFd &Fd, pid_t &Child, FileFd::OpenMode Mode);
 
 APT_HIDDEN bool OpenConfigurationFileFd(std::string const &File, FileFd &Fd);
 
-APT_HIDDEN int Inhibit(const char *what, const char *who, const char *why, const char *mode);
-
 #endif
